@@ -18,7 +18,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: affile.h,v 1.5 1999/06/08 19:47:31 bazsi Exp $
+ * $Id: affile.h,v 1.6 1999/07/10 15:58:33 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -32,7 +32,17 @@
 #include "sources.h"
 #include "destinations.h"
 
+#define AFFILE_COMPRESS   0x0001
+#define AFFILE_COMPRESS_SHIFT 0
+
+#define AFFILE_ENCRYPT    0x0002
+#define AFFILE_ENCRYPT_SHIFT 1
+
 void affile_set_syncfreq(struct log_dest_driver *affile, int syncfreq);
+
+void affile_set_compress(struct log_dest_driver *affile, int enable);
+void affile_set_encrypt(struct log_dest_driver *affile, int enable);
+
 struct log_source_driver *make_affile_source(const char *name);
 struct log_dest_driver *make_affile_dest(const char *name, int flags);
 
