@@ -18,7 +18,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afstreams.c,v 1.1 1999/06/15 20:32:34 bazsi Exp $
+ * $Id: afstreams.c,v 1.2 1999/07/10 15:58:33 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -29,18 +29,8 @@
 
 #include "afstreams.c.x"
 
-/* CLASS:
-   (class
-     (name afstreams_source)
-     (super log_source_driver)
-     (vars
-       (name string)
-       (door_name string)
-       (stream_fd object io_fd)
-       (door simple int)))
-*/
 
-#ifdef HAVE_STROPTS_H
+#if HAVE_STRLOG_H && HAVE_STROPTS_H
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -75,7 +65,7 @@ static int do_stream_read(struct abstract_read **r, UINT32 length, UINT8 *buf)
 	struct strbuf ctl, data;
 	struct log_ctl lc;
 	int flags;
-	char tmp[MAX_LINE + 1];
+	/* char tmp[MAX_LINE + 1]; */
 	int res;
 
 	ctl.maxlen = ctl.len = sizeof(lc);
@@ -85,12 +75,18 @@ static int do_stream_read(struct abstract_read **r, UINT32 length, UINT8 *buf)
 	data.buf = tmp;
 	flags = 0;
 
-	if ((res = getmsg(self->fd, &ctl, &data, &flags)) == 0) {
-		return c_format_write("<%d>%s", length, buf, lc.pri, data.len, data.buf);
+	res = getmsg(self->fd, &ctl, &data, &flags));
+	if ((res & MORECTL) == 0) {
+		int reqlen;
+		if (res & MOREDATA) {
+			werror("do_stream_read: STREAMS device gives too long line\n");
+		}
+		reqlen = c_format_length("<%d>%s", lc.pri, data.len, data.buf);
+		return c_format_write("<%d>%s", length, buf, lc.pri, data.len + (length < reqlen) ? length - reqlen : 0, data.buf);
 	}
 	else {
-		werror("do_stream_read: getmsg() failed, res=%i %z\n", res, strerror(errno));
-		return A_FAIL;
+		werror("do_stream_read: getmsg() trying to return too much ctl data, res=%i %z\n", res, strerror(errno));
+		return ST_OK | ST_GOON;
 	}
 }
 
@@ -128,11 +124,22 @@ struct io_fd *io_stream_get(struct io_fd *f,
 	return f;
 }
 
+/* CLASS:
+   (class
+     (name afstreams_source)
+     (super log_source_driver)
+     (vars
+       (name string)
+       (door_name string)
+       (stream_fd object io_fd)
+       (door simple int)))
+*/
+
 #ifdef HAVE_DOOR_H
 void afstreams_door_server_proc(void *cookie, char *argp, size_t arg_size, door_desc_t *dp, size_t n_desc)
 {
         door_return(NULL, 0, NULL, 0);
-        return 0;
+        return;
 }
 #endif
 
@@ -168,7 +175,7 @@ static int do_init_afstreams_source(struct log_handler *c, struct syslog_conf *c
 
 #ifdef HAVE_DOOR_H
 		if (self->door_name) {
-			if (stat(self->door_name->data, &st) != -1) {
+			if (stat(self->door_name->data, &st) == -1) {
 				fd = creat(self->door_name->data, 0666);
 				if (fd == -1) {
 					werror("do_init_afstreams_source: cannot create door file %S (%z)\n", self->door_name, strerror(errno));
@@ -189,7 +196,6 @@ static int do_init_afstreams_source(struct log_handler *c, struct syslog_conf *c
 			}
 			self->door = fd;
 	
-			REMEMBER_RESOURCE(cfg->resources, &make_io_fd(cfg->backend, fd)->super.super);
 		}
 #endif
 	}
@@ -212,8 +218,11 @@ static int do_destroy_afstreams_source(struct log_handler *c, struct syslog_conf
 {
 	CAST(afstreams_source, self, c);
 	
-	if (self->door != -1)
+	if (self->door != -1) {
 		door_revoke(self->door);
+		close(self->door);
+	}
+	return ST_OK | ST_GOON;
 }
 #endif
 
