@@ -18,7 +18,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: cfgfile.c,v 1.16 1999/06/06 11:36:17 bazsi Exp $
+ * $Id: cfgfile.c,v 1.17 1999/07/10 15:58:33 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -157,6 +157,8 @@ struct syslog_conf *make_syslog_conf(const char *name, struct io_backend *backen
 	self->sync_freq = 1;
 	self->mark_freq = 1200; /* 20 minutes */
 	self->long_hostnames = 1;
+	self->time_reopen = 60;
+	self->log_fifo_size = 100;
 	if ((cfg = fopen(name, "r")) != NULL) {
 		yyin = cfg;
 		res = yyparse();
@@ -167,6 +169,9 @@ struct syslog_conf *make_syslog_conf(const char *name, struct io_backend *backen
 			return self;
 		}
 	}
+	else {
+		werror("Cannot open configuration file %z for reading\n", name);
+	}
 	KILL(self);
 	configuration = NULL;
 	return NULL;
