@@ -18,7 +18,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: cfgfile.h,v 1.10 1999/05/26 09:17:56 bazsi Exp $
+ * $Id: cfgfile.h,v 1.11 1999/07/10 15:58:33 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -46,6 +46,8 @@
 	(long_hostnames simple UINT32)
 	(mark_freq simple UINT32)
 	(sync_freq simple UINT32)
+	(time_reopen simple UINT32)
+	(log_fifo_size simple UINT32)
 	; internal messages should come from this source
 	(internal object log_handler)
         (sources object log_source_group)
