@@ -25,10 +25,12 @@
 #include "syslog-ng.h"
 #include "cfgfile.h"
 #include "afinter.h"
+#include "format.h"
 #include "werror.h"
 
 #include <sys/types.h>
 #include <signal.h>
+#include <fcntl.h>
 #include <unistd.h>
 #include <errno.h>
 #include <string.h>
@@ -151,6 +153,13 @@ void go_background()
 	
 	pid = fork();
 	if (pid == 0) {
+		int fd = open(PATH_PIDFILE, O_CREAT | O_WRONLY | O_NOCTTY, 0666);
+		if (fd != -1) {
+			struct ol_string *pid_s = c_format("%i", getpid());
+			write(fd, pid_s->data, pid_s->length);
+			ol_string_free(pid_s);
+			close(fd);
+		}
 		return;
 	}
 	else if (pid == -1) {
