@@ -18,7 +18,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: syslog-ng.h,v 1.11 1999/06/08 19:47:31 bazsi Exp $
+ * $Id: syslog-ng.h,v 1.12 1999/07/10 15:58:33 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -29,10 +29,12 @@
 
 #include "objects.h"
 
-#if !WITH_DEBUG
-#define PATH_SYSLOG_NG_CONF     "/etc/syslog-ng/syslog-ng.conf"
-#else
+#if WITH_DEBUG
 #define PATH_SYSLOG_NG_CONF     "syslog-ng.conf"
+#define PATH_PIDFILE            "syslog-ng.pid"
+#else
+#define PATH_SYSLOG_NG_CONF     "/etc/syslog-ng/syslog-ng.conf"
+#define PATH_PIDFILE            "/var/run/syslog-ng.pid"
 #endif
 
 #define ST_QUIT                 16
@@ -42,8 +44,9 @@
 #define MAX_TOKEN		128
 
 /* amount of time before reopening is attempted */
-#define TIME_REOPEN             60 
+#define TIME_REOPEN             3
 
 #define LOG_FIFO_SIZE		100
 
 #endif
+
