@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: utils.h,v 1.5 1999/05/06 15:03:33 bazsi Exp $
+ * $Id: utils.h,v 1.6 1999/07/10 15:58:33 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -36,4 +36,7 @@ char *getshorthostname(char *buf, size_t bufsize);
 int inet_aton(const char *cp, struct in_addr *addr);
 #endif
 
+#define get_flags(flags, mask, shift) ((flags & mask) >> shift)
+#define set_flags(flags, mask, shift, value) ((flags & ~mask) | value << shift)
+
 #endif
